@@ -138,11 +138,11 @@ Net::Cloudflare::DNS - DNS API for Cloudflare API v4
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =cut
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 
 =head1 SYNOPSIS
@@ -171,16 +171,16 @@ After then, you can run "cpanm Net::Cloudflare::DNS" to install this module.
     my $res;
 
     # create record
-    $res = $dns->create_record(type=>"A", name=>"www.simplemail.co.in", content=>"74.81.81.81", proxied=>\1, ttl=>60);
+    $res = $dns->create_record(type=>"A", name=>"www.sample.com", content=>"74.81.81.81", proxied=>\1, ttl=>60);
 
     # get records
-    $res = $dns->get_records(name=>"www.simplemail.co.in");
+    $res = $dns->get_records(name=>"www.sample.com");
 
     # parse record id
     my $rid = $res->{result}->[0]->{id};
 
     # update record
-    $res = $dns->update_record($rid, type=>"A", name=>"www.simplemail.co.in",content=>"52.1.14.22", proxied=>\0, ttl=>60);
+    $res = $dns->update_record($rid, type=>"A", name=>"www.sample.com",content=>"52.1.14.22", proxied=>\0, ttl=>60);
 
     # delete record
     $res = $dns->delete_record($rid);
@@ -206,7 +206,7 @@ chance to setup permissions for the zone, with which you can edit zone's DNS rec
 
 =head2 create_record
 
-    my $res = $dns->create_record(type=>"A", name=>"www.simplemail.co.in",content=>"1.2.3.4",proxied=>\1,ttl=>1);
+    $dns->create_record(type=>"A", name=>"www.sample.com",content=>"1.2.3.4",proxied=>\1,ttl=>1);
 
 Create record in the zone.
 
@@ -233,7 +233,7 @@ Please read their official documentation below.
 
 =head2 update_record
 
-    $res = $dns->update_record($record_id, type=>"TXT", name=>"www.simplemail.co.in",content=>"bala bala",ttl=>1);
+    $dns->update_record($record_id, type=>"TXT", name=>"www.sample.com",content=>"bala bala",ttl=>1);
 
 Update record in the zone.
 
@@ -244,7 +244,7 @@ You can get $record_id from get_records method.
 
 =head2 delete_record
 
-    $res = $dns->delete_record($record_id);
+    $dns->delete_record($record_id);
 
 Delete record from the zone.
 
@@ -253,7 +253,7 @@ Provide $record_id as the unique argument.
 
 =head2 get_records
 
-    $res = $dns->get_records(conditions...);
+    my $res = $dns->get_records(conditions...);
 
 List records by conditions. For details please read the following documentation.
 
